#
# spec file for package kmod-testsuite
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kmod-testsuite
%define lname	libkmod2
Version:        25
Release:        lp152.8.3.2
Summary:        Testsuite of the kmod package
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/Kernel
Url:            http://www.jonmasters.org/blog/2011/12/20/libkmod-replaces-module-init-tools/
#Announce:	https://lwn.net/Articles/664801/

#Git-Web:	http://git.kernel.org/?p=utils/kernel/kmod/kmod.git;a=summary
#Git-Clone:	git://git.kernel.org/pub/scm/utils/kernel/kmod/kmod
Source:         https://www.kernel.org/pub/linux/utils/kernel/kmod/kmod-%version.tar.xz
Source2:        https://www.kernel.org/pub/linux/utils/kernel/kmod/kmod-%version.tar.sign
Patch0:         libkmod-signature-implement-pkcs7-parsing-with-asn1c.patch
Patch1:         0002-modprobe-Recognize-allow-unsupported-modules-on-comm.patch
Patch2:         0003-libkmod-config-Recognize-allow_unsupported_modules-i.patch
Patch3:         0009-libkmod-Implement-filtering-of-unsupported-modules-o.patch
Patch4:         0010-modprobe-Implement-allow-unsupported-modules.patch
Patch5:         0011-Do-not-filter-unsupported-modules-when-running-a-van.patch
Patch6:         libkmod-signature-Fix-crash-when-module-signature-is.patch
Patch7:         libkmod-signature-pkcs-7-fix-crash-when-signer-info-.patch
Patch8:         0012-modprobe-print-unsupported-status.patch
Patch9:         enum.patch
Patch10:        depmod-Prevent-module-dependency-files-missing-durin.patch
Patch11:        depmod-Prevent-module-dependency-files-corruption-du.patch
Patch12:        depmod-shut-up-gcc-insufficinet-buffer-warning.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  asn1c
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  git-core
BuildRequires:  kernel-default-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  xz
BuildRequires:  pkgconfig(liblzma) >= 4.99
BuildRequires:  pkgconfig(zlib)
Requires:       suse-module-tools
%if !0%{?is_opensuse}
ExcludeArch:    %ix86 s390
%endif
%define kdir /usr/src/linux-obj/%_target_cpu/default

%description
This spec file does not produce any binary RPMs. It just builds kmod and
runs its testsuite. It has been split off the kmod package to avoid a
buildloop with the kernel.

%prep
%setup -q -n kmod-%version
%autopatch -p1

%build
autoreconf -fi
export LDFLAGS="-Wl,-z,relro,-z,now"
# The extra --includedir gives us the possibility to detect dependent
# packages which fail to properly use pkgconfig.
%configure \
	--with-xz \
	--with-zlib \
	--includedir="%_includedir/kmod" \
	--with-rootlibdir="%_libdir" \
	--bindir="%_bindir"
make -C libkmod/pkcs7/asn1c-gen regen
make %{?_smp_mflags} V=1 KDIR="%kdir"

%install
# empty

%check
%ifarch ppc64
make check V=1 KDIR="%kdir" || echo "Warning: bypass boo#897845"
%else
make check V=1 KDIR="%kdir"
%endif

%changelog
* Fri Dec  7 2018 Michal Suchanek <msuchanek@suse.de>
- Fix module dependency file corruption on parallel invocation (bsc#1118629).
  * Add depmod-Prevent-module-dependency-files-corruption-du.patch
  * Add depmod-Prevent-module-dependency-files-missing-durin.patch
  * Add depmod-shut-up-gcc-insufficinet-buffer-warning.patch
* Wed Jul 18 2018 jengelh@inai.de
- Remove enum padding constants, add enum.patch.
* Fri Jun  8 2018 vlad.botanic@gmail.com
- allow 'modprobe -c' print the status of "allow_unsupported_modules" option.
  Add 0012-modprobe-print-unsupported-status.patch
* Fri Apr  6 2018 msuchanek@suse.com
- Fix crash when PKCS#7 signer name is not present in signature (bsc#1088244)
  Add libkmod-signature-pkcs-7-fix-crash-when-signer-info-.patch
* Fri Mar 16 2018 ro@suse.de
- for sle, buildexclude the 32bit platforms in kmod-testsuite,
  they have no kernel binaries anyway (bnc#1085640)
* Thu Mar  8 2018 msuchanek@suse.com
- Fix PKCS#7 signature display in modinfo (bsc#1077693).
  * Add libkmod-signature-implement-pkcs7-parsing-with-asn1c.patch
  * Add libkmod-signature-Fix-crash-when-module-signature-is.patch
  * Refresh 0010-modprobe-Implement-allow-unsupported-modules.patch
* Thu Feb  1 2018 msuchanek@suse.com
- Update to kmod v25
* Thu Jul  6 2017 jengelh@inai.de
- Update to new upstream release 24
  * libkmod: fix  use of strcpy
  * depmod: fix string overflow
  * depmod: ignore related modules in depmod_report_cycles
  * libkmod: Fix handling of quotes in kernel command line
  * libkmod-config: replace 0/1 with bool
  * depmod: handle nested loops
- Drop 0001-use-correct-sort-method-in-test-array.patch,
  0002-depmod-ignore-related-modules-in-depmod_report_cycle.patch,
  0009-libkmod-Implement-filtering-of-unsupported-modules-o.patch
  (applied upstream)
* Tue Nov 22 2016 yousaf.kaukab@suse.com
- 0001-testsuite-depmod-add-module-dependency-outside-cycli.patch:
  Add test case where cyclic and non-cyclic dependencies are present
  at the same time. (boo#1008186)
* Thu Mar 31 2016 normand@linux.vnet.ibm.com
- Ignore make check error of ppc64 architecture, bypass boo#897845
* Mon Dec  7 2015 jengelh@inai.de
- Update to new upstream release 22
  * support `insmod -f`
  * depmod: do not fall back to uname on bad version
* Sat Nov  7 2015 jengelh@inai.de
- Update to new upstream release 21
  * Cache built modules so it is easier to run "make check" on
  build servers by distro maintainers. If kmod is configured with
  - -disable-test-modules, the modules from cache will be used by
  "make check". No changes to the tests are needed and all of
  them can run fine.
- Specify KDIR explicitly to resolve build failure with `osc build`
  (because kmod uses `uname -r` and the kernel versions need not
  match between build env and local host)
* Tue Apr 21 2015 mmarek@suse.cz
- Run the kmod testsuite in a separate build, to avoid a buildloop
  with the kernel.
